@@ -169,7 +169,7 @@ type Local interface {
 	// backend's implementations of this to understand what this actually
 	// does, because this operation has no well-defined contract aside from
 	// "whatever it already does".
-	LocalRun(*Operation) (*LocalRun, statemgr.Full, tfdiags.Diagnostics)
+	LocalRun(context.Context, *Operation) (*LocalRun, statemgr.Full, tfdiags.Diagnostics)
 }
 
 // LocalRun represents the assortment of objects that we can collect or
@@ -282,6 +282,7 @@ type Operation struct {
 	PlanMode     plans.Mode
 	AutoApprove  bool
 	Targets      []addrs.Targetable
+	Excludes     []addrs.Targetable
 	ForceReplace []addrs.AbsResourceInstance
 	// Injected by the command creating the operation (plan/apply/refresh/etc...)
 	Variables map[string]UnparsedVariableValue
