@@ -130,7 +130,7 @@ func (c *httpClient) Lock(info *statemgr.LockInfo) (string, error) {
 			}
 		}
 		return "", &statemgr.LockError{
-			Info: info,
+			Info: &existing,
 			Err:  fmt.Errorf("HTTP remote state already locked: ID=%s", existing.ID),
 		}
 	default:
@@ -278,3 +278,7 @@ func (c *httpClient) Delete() error {
 		return fmt.Errorf("HTTP error: %d", resp.StatusCode)
 	}
 }
+
+func (c *httpClient) IsLockingEnabled() bool {
+	return c.UnlockURL != nil
+}
