@@ -351,6 +351,7 @@ func TestCloud_config(t *testing.T) {
 		config  cty.Value
 		confErr string
 		valErr  string
+		envVars map[string]string
 	}{
 		"with_a_non_tfe_host": {
 			config: cty.ObjectVal(map[string]cty.Value{
@@ -440,10 +441,33 @@ func TestCloud_config(t *testing.T) {
 		"null config": {
 			config: cty.NullVal(cty.EmptyObject),
 		},
+		"with_tags_and_TF_WORKSPACE_env_var_not_matching_tags": { //TODO: once we have proper e2e backend testing we should also add the opposite test - with_tags_and_TF_WORKSPACE_env_var_matching_tags
+			config: cty.ObjectVal(map[string]cty.Value{
+				"hostname":     cty.NullVal(cty.String),
+				"organization": cty.StringVal("opentofu"),
+				"token":        cty.NullVal(cty.String),
+				"workspaces": cty.ObjectVal(map[string]cty.Value{
+					"tags": cty.SetVal(
+						[]cty.Value{
+							cty.StringVal("billing"),
+						},
+					),
+					"project": cty.NullVal(cty.String),
+				}),
+			}),
+			envVars: map[string]string{
+				"TF_WORKSPACE": "my-workspace",
+			},
+			confErr: `OpenTofu failed to find workspace my-workspace with the tags specified in your configuration`,
+		},
 	}
 
 	for name, tc := range cases {
 		t.Run(name, func(t *testing.T) {
+			for k, v := range tc.envVars {
+				t.Setenv(k, v)
+			}
+
 			b, cleanup := testUnconfiguredBackend(t)
 			t.Cleanup(cleanup)
 
@@ -660,7 +684,7 @@ func TestCloud_setConfigurationFieldsHappyPath(t *testing.T) {
 			},
 			expectedForceLocal: true,
 		},
-		"with hostname and workspace tags set, and tags overwritten by TF_WORKSPACE": {
+		"with hostname and workspace tags set, then tags should not be overwritten by TF_WORKSPACE": {
 			// see: https://github.com/opentofu/opentofu/issues/814
 			obj: cty.ObjectVal(map[string]cty.Value{
 				"organization": cty.NullVal(cty.String),
@@ -675,25 +699,24 @@ func TestCloud_setConfigurationFieldsHappyPath(t *testing.T) {
 				"TF_WORKSPACE": "foo",
 			},
 			expectedHostname:      "opentofu.org",
-			expectedWorkspaceName: "foo",
-			expectedWorkspaceTags: nil,
+			expectedWorkspaceName: "",
+			expectedWorkspaceTags: map[string]struct{}{"foo": {}, "bar": {}},
 		},
-		"with hostname and workspace name set, and TF_WORKSPACE specified": {
+		"with hostname and workspace name set, and workspace name the same as provided TF_WORKSPACE": {
 			obj: cty.ObjectVal(map[string]cty.Value{
 				"organization": cty.NullVal(cty.String),
 				"hostname":     cty.StringVal("opentofu.org"),
 				"workspaces": cty.ObjectVal(map[string]cty.Value{
-					"name":    cty.StringVal("old"),
+					"name":    cty.StringVal("my-workspace"),
 					"tags":    cty.NullVal(cty.Set(cty.String)),
 					"project": cty.NullVal(cty.String),
 				}),
 			}),
 			envVars: map[string]string{
-				"TF_WORKSPACE": "new",
+				"TF_WORKSPACE": "my-workspace",
 			},
 			expectedHostname:      "opentofu.org",
-			expectedWorkspaceName: "old",
-			expectedWorkspaceTags: nil,
+			expectedWorkspaceName: "my-workspace",
 		},
 		"with hostname and project set, and project overwritten by TF_CLOUD_PROJECT": {
 			obj: cty.ObjectVal(map[string]cty.Value{
@@ -858,22 +881,21 @@ func TestCloud_setConfigurationFieldsUnhappyPath(t *testing.T) {
 			wantSummary: "Hostname is required for the cloud backend",
 			wantDetail:  `OpenTofu does not provide a default "hostname" attribute, so it must be set to the hostname of the cloud backend.`,
 		},
-		"with hostname and workspace tags set, and tags overwritten by TF_WORKSPACE": {
-			// see: https://github.com/opentofu/opentofu/issues/814
+		"with hostname and workspace name set, and workspace name is not the same as provided TF_WORKSPACE": {
 			obj: cty.ObjectVal(map[string]cty.Value{
 				"organization": cty.NullVal(cty.String),
 				"hostname":     cty.StringVal("opentofu.org"),
 				"workspaces": cty.ObjectVal(map[string]cty.Value{
-					"name":    cty.NullVal(cty.String),
-					"tags":    cty.SetVal([]cty.Value{cty.StringVal("foo"), cty.StringVal("bar")}),
+					"name":    cty.StringVal("my-workspace"),
+					"tags":    cty.NullVal(cty.Set(cty.String)),
 					"project": cty.NullVal(cty.String),
 				}),
 			}),
 			envVars: map[string]string{
 				"TF_WORKSPACE": "qux",
 			},
-			wantSummary: invalidWorkspaceConfigMisconfigurationEnvVar.Description().Summary,
-			wantDetail:  invalidWorkspaceConfigMisconfigurationEnvVar.Description().Detail,
+			wantSummary: invalidWorkspaceConfigInconsistentNameAndEnvVar().Description().Summary,
+			wantDetail:  invalidWorkspaceConfigInconsistentNameAndEnvVar().Description().Detail,
 		},
 	}
 
