@@ -34,7 +34,7 @@ type State struct {
 	LockTimeout time.Duration
 
 	// StatePath specifies a non-default location for the state file. The
-	// default value is blank, which is interpeted as "terraform.tfstate".
+	// default value is blank, which is interpreted as "terraform.tfstate".
 	StatePath string
 
 	// StateOutPath specifies a different path to write the final state file.
@@ -69,6 +69,10 @@ type Operation struct {
 	// their dependencies.
 	Targets []addrs.Targetable
 
+	// Excludes allow limiting an operation to execute on all resources other
+	// than a set of excluded resource addresses and resources dependent on them.
+	Excludes []addrs.Targetable
+
 	// ForceReplace addresses cause OpenTofu to force a particular set of
 	// resource instances to generate "replace" actions in any plan where they
 	// would normally have generated "no-op" or "update" actions.
@@ -85,25 +89,25 @@ type Operation struct {
 	// method Parse to populate the exported fields from these, validating
 	// the raw values in the process.
 	targetsRaw      []string
+	excludesRaw     []string
 	forceReplaceRaw []string
 	destroyRaw      bool
 	refreshOnlyRaw  bool
 }
 
-// Parse must be called on Operation after initial flag parse. This processes
-// the raw target flags into addrs.Targetable values, returning diagnostics if
-// invalid.
-func (o *Operation) Parse() tfdiags.Diagnostics {
+// parseTargetables gets a list of strings, each representing a targetable object, and returns a list of
+// addrs.Targetable
+// This is used for parsing the input of -target and -exclude flags
+func parseTargetables(rawTargetables []string, flag string) ([]addrs.Targetable, tfdiags.Diagnostics) {
+	var targetables []addrs.Targetable
 	var diags tfdiags.Diagnostics
 
-	o.Targets = nil
-
-	for _, tr := range o.targetsRaw {
+	for _, tr := range rawTargetables {
 		traversal, syntaxDiags := hclsyntax.ParseTraversalAbs([]byte(tr), "", hcl.Pos{Line: 1, Column: 1})
 		if syntaxDiags.HasErrors() {
 			diags = diags.Append(tfdiags.Sourceless(
 				tfdiags.Error,
-				fmt.Sprintf("Invalid target %q", tr),
+				fmt.Sprintf("Invalid %s %q", flag, tr),
 				syntaxDiags[0].Detail,
 			))
 			continue
@@ -113,14 +117,50 @@ func (o *Operation) Parse() tfdiags.Diagnostics {
 		if targetDiags.HasErrors() {
 			diags = diags.Append(tfdiags.Sourceless(
 				tfdiags.Error,
-				fmt.Sprintf("Invalid target %q", tr),
+				fmt.Sprintf("Invalid %s %q", flag, tr),
 				targetDiags[0].Description().Detail,
 			))
 			continue
 		}
 
-		o.Targets = append(o.Targets, target.Subject)
+		targetables = append(targetables, target.Subject)
 	}
+	return targetables, diags
+}
+
+func parseRawTargetsAndExcludes(targets []string, excludes []string) ([]addrs.Targetable, []addrs.Targetable, tfdiags.Diagnostics) {
+	var parsedTargets []addrs.Targetable
+	var parsedExcludes []addrs.Targetable
+	var diags tfdiags.Diagnostics
+
+	if len(targets) > 0 && len(excludes) > 0 {
+		diags = diags.Append(tfdiags.Sourceless(
+			tfdiags.Error,
+			"Invalid combination of arguments",
+			"-target and -exclude flags cannot be used together. Please remove one of the flags",
+		))
+		return parsedTargets, parsedExcludes, diags
+	}
+
+	var parseDiags tfdiags.Diagnostics
+	parsedTargets, parseDiags = parseTargetables(targets, "target")
+	diags = diags.Append(parseDiags)
+
+	parsedExcludes, parseDiags = parseTargetables(excludes, "exclude")
+	diags = diags.Append(parseDiags)
+
+	return parsedTargets, parsedExcludes, diags
+}
+
+// Parse must be called on Operation after initial flag parse. This processes
+// the raw target flags into addrs.Targetable values, returning diagnostics if
+// invalid.
+func (o *Operation) Parse() tfdiags.Diagnostics {
+	var diags tfdiags.Diagnostics
+
+	var parseDiags tfdiags.Diagnostics
+	o.Targets, o.Excludes, parseDiags = parseRawTargetsAndExcludes(o.targetsRaw, o.excludesRaw)
+	diags = diags.Append(parseDiags)
 
 	for _, raw := range o.forceReplaceRaw {
 		traversal, syntaxDiags := hclsyntax.ParseTraversalAbs([]byte(raw), "", hcl.Pos{Line: 1, Column: 1})
@@ -183,7 +223,7 @@ func (o *Operation) Parse() tfdiags.Diagnostics {
 }
 
 // Vars describes arguments which specify non-default variable values. This
-// interfce is unfortunately obscure, because the order of the CLI arguments
+// interface is unfortunately obscure, because the order of the CLI arguments
 // determines the final value of the gathered variables. In future it might be
 // desirable for the arguments package to handle the gathering of variables
 // directly, returning a map of variable values.
@@ -230,10 +270,11 @@ func extendedFlagSet(name string, state *State, operation *Operation, vars *Vars
 		f.BoolVar(&operation.destroyRaw, "destroy", false, "destroy")
 		f.BoolVar(&operation.refreshOnlyRaw, "refresh-only", false, "refresh-only")
 		f.Var((*flagStringSlice)(&operation.targetsRaw), "target", "target")
+		f.Var((*flagStringSlice)(&operation.excludesRaw), "exclude", "exclude")
 		f.Var((*flagStringSlice)(&operation.forceReplaceRaw), "replace", "replace")
 	}
 
-	// Gather all -var and -var-file arguments into one heterogenous structure
+	// Gather all -var and -var-file arguments into one heterogeneous structure
 	// to preserve the overall order.
 	if vars != nil {
 		varsFlags := newFlagNameValueSlice("-var")
