@@ -1,9 +1,12 @@
-// Copyright (c) HashiCorp, Inc.
+// Copyright (c) The OpenTofu Authors
+// SPDX-License-Identifier: MPL-2.0
+// Copyright (c) 2023 HashiCorp, Inc.
 // SPDX-License-Identifier: MPL-2.0
 
 package renderers
 
 import (
+	"bytes"
 	"encoding/json"
 	"fmt"
 	"strings"
@@ -31,7 +34,9 @@ func evaluatePrimitiveString(value interface{}, opts computed.RenderHumanOpts) e
 
 	if strings.HasPrefix(str, "{") || strings.HasPrefix(str, "[") {
 		var jv interface{}
-		if err := json.Unmarshal([]byte(str), &jv); err == nil {
+		decoder := json.NewDecoder(bytes.NewBufferString(str))
+		decoder.UseNumber()
+		if err := decoder.Decode(&jv); err == nil {
 			return evaluatedString{
 				String: str,
 				Json:   jv,
