@@ -23,6 +23,8 @@ type PlanCommand struct {
 }
 
 func (c *PlanCommand) Run(rawArgs []string) int {
+	ctx := c.CommandContext()
+
 	// Parse and apply global view arguments
 	common, rawArgs := arguments.ParseView(rawArgs)
 	c.View.Configure(common)
@@ -36,6 +38,8 @@ func (c *PlanCommand) Run(rawArgs []string) int {
 	// Parse and validate flags
 	args, diags := arguments.ParsePlan(rawArgs)
 
+	c.View.SetShowSensitive(args.ShowSensitive)
+
 	// Instantiate the view, even if there are flag errors, so that we render
 	// diagnostics according to the desired view
 	view := views.NewPlan(args.ViewType, c.View)
@@ -103,7 +107,7 @@ func (c *PlanCommand) Run(rawArgs []string) int {
 	diags = nil
 
 	// Perform the operation
-	op, diags := c.RunOperation(be, opReq)
+	op, diags := c.RunOperation(ctx, be, opReq)
 	view.Diagnostics(diags)
 	if diags.HasErrors() {
 		return 1
@@ -164,6 +168,7 @@ func (c *PlanCommand) OperationRequest(
 	opReq.PlanOutPath = planOutPath
 	opReq.GenerateConfigOut = generateConfigOut
 	opReq.Targets = args.Targets
+	opReq.Excludes = args.Excludes
 	opReq.ForceReplace = args.ForceReplace
 	opReq.Type = backend.OperationTypePlan
 	opReq.View = view.Operation()
@@ -180,7 +185,7 @@ func (c *PlanCommand) OperationRequest(
 
 func (c *PlanCommand) GatherVariables(args *arguments.Vars) {
 	// FIXME the arguments package currently trivially gathers variable related
-	// arguments in a heterogenous slice, in order to minimize the number of
+	// arguments in a heterogeneous slice, in order to minimize the number of
 	// code paths gathering variables during the transition to this structure.
 	// Once all commands that gather variables have been converted to this
 	// structure, we could move the variable gathering code to the arguments
@@ -236,7 +241,14 @@ Plan Customization Options:
                       resource, or resource instance and all of its
                       dependencies. You can use this option multiple times to
                       include more than one object. This is for exceptional
-                      use only.
+                      use only. Cannot be used alongside the -exclude flag
+
+  -exclude=resource   Limit the planning operation to not operate on the given
+                      module, resource, or resource instance and all of the
+                      resources and modules that depend on it. You can use this
+                      option multiple times to exclude more than one object.
+                      This is for exceptional use only. Cannot be used alongside
+                      the -target flag
 
   -var 'foo=bar'      Set a value for one of the input variables in the root
                       module of the configuration. Use this option more than
@@ -253,6 +265,14 @@ Other Options:
                              accompanied by errors, shows them in a more compact
                              form that includes only the summary messages.
 
+  -consolidate-warnings      If OpenTofu produces any warnings, no consolodation
+                             will be performed. All locations, for all warnings
+                             will be listed. Enabled by default.
+
+  -consolidate-errors        If OpenTofu produces any errors, no consolodation
+                             will be performed. All locations, for all errors
+                             will be listed. Disabled by default
+
   -detailed-exitcode         Return detailed exit codes when the command exits.
                              This will change the meaning of exit codes to:
                              0 - Succeeded, diff is empty (no changes)
@@ -288,6 +308,8 @@ Other Options:
   -state=statefile           A legacy option used for the local backend only.
                              See the local backend's documentation for more
                              information.
+
+  -show-sensitive            If specified, sensitive values will be displayed.
 `
 	return strings.TrimSpace(helpText)
 }
