@@ -187,7 +187,7 @@ func (c *UntaintCommand) Run(args []string) int {
 	}
 
 	obj.Status = states.ObjectReady
-	ss.SetResourceInstanceCurrent(addr, obj, rs.ProviderConfig)
+	ss.SetResourceInstanceCurrent(addr, obj, rs.ProviderConfig, is.ProviderKey)
 
 	if err := stateMgr.WriteState(state); err != nil {
 		c.Ui.Error(fmt.Sprintf("Error writing state file: %s", err))
