@@ -26,17 +26,17 @@ func TestNewDiagnostic(t *testing.T) {
 	// Common HCL for diags with source ranges. This does not have any real
 	// semantic errors, but we can synthesize fake HCL errors which will
 	// exercise the diagnostic rendering code using this
-	sources := map[string][]byte{
-		"test.tf": []byte(`resource "test_resource" "test" {
+	sources := map[string]*hcl.File{
+		"test.tf": {Bytes: []byte(`resource "test_resource" "test" {
   foo = var.boop["hello!"]
   bar = {
     baz = maybe
   }
 }
-`),
-		"short.tf":       []byte("bad source code"),
-		"odd-comment.tf": []byte("foo\n\n#\n"),
-		"values.tf": []byte(`[
+`)},
+		"short.tf":       {Bytes: []byte("bad source code")},
+		"odd-comment.tf": {Bytes: []byte("foo\n\n#\n")},
+		"values.tf": {Bytes: []byte(`[
   var.a,
   var.b,
   var.c,
@@ -49,7 +49,7 @@ func TestNewDiagnostic(t *testing.T) {
   var.j,
   var.k,
 ]
-`),
+`)},
 	}
 	testCases := map[string]struct {
 		diag interface{} // allow various kinds of diags
@@ -918,8 +918,8 @@ func TestNewDiagnostic(t *testing.T) {
 			}
 
 			// Don't care about leading or trailing whitespace
-			gotString := strings.TrimSpace(string(gotBytes))
-			wantString := strings.TrimSpace(string(wantBytes))
+			gotString := normaliseNewlines(strings.TrimSpace(string(gotBytes)))
+			wantString := normaliseNewlines(strings.TrimSpace(string(wantBytes)))
 
 			if !cmp.Equal(wantString, gotString) {
 				t.Fatalf("wrong result\n:%s", cmp.Diff(wantString, gotString))
@@ -928,6 +928,11 @@ func TestNewDiagnostic(t *testing.T) {
 	}
 }
 
+// Function to normalise newlines in a string for Windows
+func normaliseNewlines(s string) string {
+	return strings.ReplaceAll(s, "\r\n", "\n")
+}
+
 // Helper function to make constructing literal Diagnostics easier. There
 // are fields which are pointer-to-string to ensure that the rendered JSON
 // results in `null` for an empty value, rather than `""`.
