@@ -218,7 +218,7 @@ func (c *WorkspaceDeleteCommand) AutocompleteFlags() complete.Flags {
 
 func (c *WorkspaceDeleteCommand) Help() string {
 	helpText := `
-Usage: tofu [global options] workspace delete [OPTIONS] NAME
+Usage: tofu [global options] workspace delete [options] NAME
 
   Delete a OpenTofu workspace
 
