@@ -7,6 +7,7 @@ package getproviders
 
 import (
 	"context"
+	"strings"
 	"testing"
 
 	"github.com/apparentlymart/go-versions/versions"
@@ -125,6 +126,30 @@ func TestFilesystemMirrorSourceAvailableVersions(t *testing.T) {
 	}
 }
 
+func TestFilesystemMirrorSourceAvailableVersions_Unspecified(t *testing.T) {
+	unspecifiedProvider := addrs.Provider{
+		Hostname:  svchost.Hostname("registry.opentofu.org"),
+		Namespace: "testnamespace",
+		Type:      "unspecified",
+	}
+	source := NewFilesystemMirrorSource("testdata/filesystem-mirror-unspecified")
+	got, warn, err := source.AvailableVersions(context.Background(), unspecifiedProvider)
+	if err != nil {
+		t.Fatal(err)
+	}
+	// Check that we got the unspecified version
+	if len(got) != 1 || got[0] != versions.Unspecified {
+		t.Fatalf("expected unspecified version, got %v", got)
+	}
+	// We should have unspecified (0.0.0) version warning
+	if len(warn) != 1 {
+		t.Fatalf("expected 1 warning, got %v", warn)
+	}
+	warningBit := "unspecified (0.0.0) version available in the filesystem mirror"
+	if !strings.Contains(warn[0], warningBit) {
+		t.Fatalf("expected warning to contain %q, got %q", warningBit, warn[0])
+	}
+}
 func TestFilesystemMirrorSourcePackageMeta(t *testing.T) {
 	t.Run("available platform", func(t *testing.T) {
 		source := NewFilesystemMirrorSource("testdata/filesystem-mirror")
