@@ -1,4 +1,6 @@
-// Copyright (c) HashiCorp, Inc.
+// Copyright (c) The OpenTofu Authors
+// SPDX-License-Identifier: MPL-2.0
+// Copyright (c) 2023 HashiCorp, Inc.
 // SPDX-License-Identifier: MPL-2.0
 
 package plugin
@@ -94,6 +96,25 @@ func providerProtoSchema() *proto.GetProviderSchema_Response {
 				},
 			},
 		},
+		Functions: map[string]*proto.Function{
+			"fn": &proto.Function{
+				Parameters: []*proto.Function_Parameter{{
+					Name:               "par_a",
+					Type:               []byte(`"string"`),
+					AllowNullValue:     false,
+					AllowUnknownValues: false,
+				}},
+				VariadicParameter: &proto.Function_Parameter{
+					Name:               "par_var",
+					Type:               []byte(`"string"`),
+					AllowNullValue:     true,
+					AllowUnknownValues: false,
+				},
+				Return: &proto.Function_Return{
+					Type: []byte(`"string"`),
+				},
+			},
+		},
 	}
 }
 
@@ -146,7 +167,7 @@ func TestGRPCProvider_GetSchema_GlobalCacheEnabled(t *testing.T) {
 		gomock.Any(),
 	).Times(1).Return(&proto.GetProviderSchema_Response{
 		Provider:           mockedProviderResponse,
-		ServerCapabilities: &proto.GetProviderSchema_ServerCapabilities{GetProviderSchemaOptional: true},
+		ServerCapabilities: &proto.ServerCapabilities{GetProviderSchemaOptional: true},
 	}, nil)
 
 	// Run GetProviderTwice, expect GetSchema to be called once
@@ -193,7 +214,7 @@ func TestGRPCProvider_GetSchema_GlobalCacheDisabled(t *testing.T) {
 		gomock.Any(),
 	).Times(2).Return(&proto.GetProviderSchema_Response{
 		Provider:           mockedProviderResponse,
-		ServerCapabilities: &proto.GetProviderSchema_ServerCapabilities{GetProviderSchemaOptional: false},
+		ServerCapabilities: &proto.ServerCapabilities{GetProviderSchemaOptional: false},
 	}, nil)
 
 	// Run GetProviderTwice, expect GetSchema to be called once
@@ -874,3 +895,29 @@ func TestGRPCProvider_ReadDataSourceJSON(t *testing.T) {
 		t.Fatal(cmp.Diff(expected, resp.State, typeComparer, valueComparer, equateEmpty))
 	}
 }
+
+func TestGRPCProvider_CallFunction(t *testing.T) {
+	client := mockProviderClient(t)
+	p := &GRPCProvider{
+		client: client,
+	}
+
+	client.EXPECT().CallFunction(
+		gomock.Any(),
+		gomock.Any(),
+	).Return(&proto.CallFunction_Response{
+		Result: &proto.DynamicValue{Json: []byte(`"foo"`)},
+	}, nil)
+
+	resp := p.CallFunction(providers.CallFunctionRequest{
+		Name:      "fn",
+		Arguments: []cty.Value{cty.StringVal("bar"), cty.NilVal},
+	})
+
+	if resp.Error != nil {
+		t.Fatal(resp.Error)
+	}
+	if resp.Result != cty.StringVal("foo") {
+		t.Fatalf("%v", resp.Result)
+	}
+}
