@@ -658,7 +658,7 @@ func TestEnsureProviderVersions(t *testing.T) {
 			LockFile: `
 				# This is approximating the awkward situation where the lock
 				# file was populated by someone who installed from a location
-				# other than the origin registry annd so the set of checksums
+				# other than the origin registry and so the set of checksums
 				# is incomplete. In this case we can't prove that our cache
 				# entry is valid and so we silently ignore the cache entry
 				# and try to install from upstream anyway, in the hope that
@@ -2315,6 +2315,12 @@ func TestEnsureProviderVersions_local_source(t *testing.T) {
 			wantHash: getproviders.NilHash, // installation fails for a provider with no executable
 			err:      "provider binary not found: could not find executable file starting with terraform-provider-executable",
 		},
+		"unspecified-version": {
+			provider: "null",
+			version:  "0.0.0",
+			wantHash: getproviders.NilHash,
+			err:      "0.0.0 is not a valid provider version. \nIf the version 0.0.0 is intended to represent a non-published provider, consider using dev_overrides - https://opentofu.org/docs/cli/config/config-file/#development-overrides-for-provider-developers",
+		},
 	}
 
 	for name, test := range tests {
