@@ -6,16 +6,15 @@
 package tofu
 
 import (
+	"context"
 	"fmt"
 	"log"
 	"strings"
 
+	"github.com/opentofu/opentofu/internal/addrs"
+	"github.com/opentofu/opentofu/internal/dag"
 	"github.com/opentofu/opentofu/internal/logging"
 	"github.com/opentofu/opentofu/internal/tfdiags"
-
-	"github.com/opentofu/opentofu/internal/addrs"
-
-	"github.com/opentofu/opentofu/internal/dag"
 )
 
 // Graph represents the graph that OpenTofu uses to represent resources
@@ -36,13 +35,13 @@ func (g *Graph) DirectedGraph() dag.Grapher {
 // Walk walks the graph with the given walker for callbacks. The graph
 // will be walked with full parallelism, so the walker should expect
 // to be called in concurrently.
-func (g *Graph) Walk(walker GraphWalker) tfdiags.Diagnostics {
-	return g.walk(walker)
+func (g *Graph) Walk(ctx context.Context, walker GraphWalker) tfdiags.Diagnostics {
+	return g.walk(ctx, walker)
 }
 
-func (g *Graph) walk(walker GraphWalker) tfdiags.Diagnostics {
+func (g *Graph) walk(ctx context.Context, walker GraphWalker) tfdiags.Diagnostics {
 	// The callbacks for enter/exiting a graph
-	ctx := walker.EvalContext()
+	evalCtx := walker.EvalContext()
 
 	// We explicitly create the panicHandler before
 	// spawning many go routines for vertex evaluation
@@ -75,7 +74,7 @@ func (g *Graph) walk(walker GraphWalker) tfdiags.Diagnostics {
 		// vertexCtx is the context that we use when evaluating. This
 		// is normally the context of our graph but can be overridden
 		// with a GraphNodeModuleInstance impl.
-		vertexCtx := ctx
+		vertexCtx := evalCtx
 		if pn, ok := v.(GraphNodeModuleInstance); ok {
 			vertexCtx = walker.EnterPath(pn.Path())
 			defer walker.ExitPath(pn.Path())
@@ -124,7 +123,7 @@ func (g *Graph) walk(walker GraphWalker) tfdiags.Diagnostics {
 
 				// Walk the subgraph
 				log.Printf("[TRACE] vertex %q: entering dynamic subgraph", dag.VertexName(v))
-				subDiags := g.walk(walker)
+				subDiags := g.walk(ctx, walker)
 				diags = diags.Append(subDiags)
 				if subDiags.HasErrors() {
 					var errs []string
