@@ -31,21 +31,22 @@ type ContextGraphWalker struct {
 	NullGraphWalker
 
 	// Configurable values
-	Context            *Context
-	State              *states.SyncState       // Used for safe concurrent access to state
-	RefreshState       *states.SyncState       // Used for safe concurrent access to state
-	PrevRunState       *states.SyncState       // Used for safe concurrent access to state
-	Changes            *plans.ChangesSync      // Used for safe concurrent writes to changes
-	Checks             *checks.State           // Used for safe concurrent writes of checkable objects and their check results
-	InstanceExpander   *instances.Expander     // Tracks our gradual expansion of module and resource instances
-	ImportResolver     *ImportResolver         // Tracks import targets as they are being resolved
-	MoveResults        refactoring.MoveResults // Read-only record of earlier processing of move statements
-	Operation          walkOperation
-	StopContext        context.Context
-	RootVariableValues InputValues
-	Config             *configs.Config
-	PlanTimestamp      time.Time
-	Encryption         encryption.Encryption
+	Context                 *Context
+	State                   *states.SyncState       // Used for safe concurrent access to state
+	RefreshState            *states.SyncState       // Used for safe concurrent access to state
+	PrevRunState            *states.SyncState       // Used for safe concurrent access to state
+	Changes                 *plans.ChangesSync      // Used for safe concurrent writes to changes
+	Checks                  *checks.State           // Used for safe concurrent writes of checkable objects and their check results
+	InstanceExpander        *instances.Expander     // Tracks our gradual expansion of module and resource instances
+	ImportResolver          *ImportResolver         // Tracks import targets as they are being resolved
+	MoveResults             refactoring.MoveResults // Read-only record of earlier processing of move statements
+	Operation               walkOperation
+	StopContext             context.Context
+	RootVariableValues      InputValues
+	Config                  *configs.Config
+	PlanTimestamp           time.Time
+	Encryption              encryption.Encryption
+	ProviderFunctionTracker ProviderFunctionMapping
 
 	// This is an output. Do not set this, nor read it while a graph walk
 	// is in progress.
@@ -59,7 +60,7 @@ type ContextGraphWalker struct {
 	variableValues     map[string]map[string]cty.Value
 
 	providerLock  sync.Mutex
-	providerCache map[string]providers.Interface
+	providerCache map[string]map[addrs.InstanceKey]providers.Interface
 
 	provisionerLock  sync.Mutex
 	provisionerCache map[string]provisioners.Interface
@@ -99,27 +100,28 @@ func (w *ContextGraphWalker) EvalContext() EvalContext {
 	}
 
 	ctx := &BuiltinEvalContext{
-		StopContext:           w.StopContext,
-		Hooks:                 w.Context.hooks,
-		InputValue:            w.Context.uiInput,
-		InstanceExpanderValue: w.InstanceExpander,
-		Plugins:               w.Context.plugins,
-		MoveResultsValue:      w.MoveResults,
-		ImportResolverValue:   w.ImportResolver,
-		ProviderCache:         w.providerCache,
-		ProviderInputConfig:   w.Context.providerInputConfig,
-		ProviderLock:          &w.providerLock,
-		ProvisionerCache:      w.provisionerCache,
-		ProvisionerLock:       &w.provisionerLock,
-		ChangesValue:          w.Changes,
-		ChecksValue:           w.Checks,
-		StateValue:            w.State,
-		RefreshStateValue:     w.RefreshState,
-		PrevRunStateValue:     w.PrevRunState,
-		Evaluator:             evaluator,
-		VariableValues:        w.variableValues,
-		VariableValuesLock:    &w.variableValuesLock,
-		Encryption:            w.Encryption,
+		StopContext:             w.StopContext,
+		Hooks:                   w.Context.hooks,
+		InputValue:              w.Context.uiInput,
+		InstanceExpanderValue:   w.InstanceExpander,
+		Plugins:                 w.Context.plugins,
+		MoveResultsValue:        w.MoveResults,
+		ImportResolverValue:     w.ImportResolver,
+		ProviderCache:           w.providerCache,
+		ProviderInputConfig:     w.Context.providerInputConfig,
+		ProviderLock:            &w.providerLock,
+		ProvisionerCache:        w.provisionerCache,
+		ProvisionerLock:         &w.provisionerLock,
+		ChangesValue:            w.Changes,
+		ChecksValue:             w.Checks,
+		StateValue:              w.State,
+		RefreshStateValue:       w.RefreshState,
+		PrevRunStateValue:       w.PrevRunState,
+		Evaluator:               evaluator,
+		VariableValues:          w.variableValues,
+		VariableValuesLock:      &w.variableValuesLock,
+		Encryption:              w.Encryption,
+		ProviderFunctionTracker: w.ProviderFunctionTracker,
 	}
 
 	return ctx
@@ -127,7 +129,7 @@ func (w *ContextGraphWalker) EvalContext() EvalContext {
 
 func (w *ContextGraphWalker) init() {
 	w.contexts = make(map[string]*BuiltinEvalContext)
-	w.providerCache = make(map[string]providers.Interface)
+	w.providerCache = make(map[string]map[addrs.InstanceKey]providers.Interface)
 	w.provisionerCache = make(map[string]provisioners.Interface)
 	w.variableValues = make(map[string]map[string]cty.Value)
 
